==> proc-10.1.68.tar.gz: proc/src/ProcAccessControlHandler.php <==
<?php

namespace Drupal\proc;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Access\AccessResultNeutral;
use Drupal\Core\Access\AccessResultReasonInterface;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the proc entity.
 *
 * @SuppressWarnings(PHPMD.StaticAccess)
 */
class ProcAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account): AccessResultReasonInterface|AccessResultNeutral|AccessResult|AccessResultAllowed|AccessResultInterface {
    $admin_permission = $this->entityType->getAdminPermission();
    if ($account->hasPermission($admin_permission)) {
      return AccessResult::allowed();
    }
    return match ($operation) {
      'view' => AccessResult::allowedIfHasPermission($account, 'view proc entity'),
      'update' => AccessResult::allowedIfHasPermission($account, 'edit proc entity'),
      'delete' => AccessResult::allowedIfHasPermission($account, 'delete proc entity'),
      default => AccessResult::neutral(),
    };
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL): AccessResultReasonInterface|AccessResult|AccessResultAllowed|AccessResultInterface {
    $admin_permission = $this->entityType->getAdminPermission();
    if ($account->hasPermission($admin_permission)) {
      return AccessResult::allowed();
    }
    return AccessResult::allowedIfHasPermission($account, 'add proc entity');
  }

}

==> proc-10.1.71.tar.gz: proc/src/ProcAccessControlHandler.php <==
<?php

namespace Drupal\proc;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Access\AccessResultNeutral;
use Drupal\Core\Access\AccessResultReasonInterface;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the proc entity.
 *
 * @SuppressWarnings(PHPMD.StaticAccess)
 */
class ProcAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    $admin_permission = $this->entityType->getAdminPermission();
    if ($account->hasPermission($admin_permission)) {
      return AccessResult::allowed();
    }
    return match ($operation) {
      'view' => AccessResult::allowedIfHasPermission($account, 'view proc entity'),
      'update' => AccessResult::allowedIfHasPermission($account, 'edit proc entity'),
      'delete' => AccessResult::allowedIfHasPermission($account, 'delete proc entity'),
      default => AccessResult::neutral(),
    };
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL): AccessResultReasonInterface|AccessResult|AccessResultAllowed|AccessResultInterface {
    $admin_permission = $this->entityType->getAdminPermission();
    if ($account->hasPermission($admin_permission)) {
      return AccessResult::allowed();
    }
    return AccessResult::allowedIfHasPermission($account, 'add proc entity');
  }

}
